@@ -2,14 +2,15 @@
 
 __author__ = """Yunseong Hwang"""
 __email__ = 'kika1492@gmail.com'
-__version__ = '0.1.12'
+__version__ = '0.1.13'
 
+import sys
 import koapy.config
 
 from koapy.context.KiwoomOpenApiContext import KiwoomOpenApiContext
 
-from koapy.pyqt5.KiwoomOpenApiQAxWidget import KiwoomOpenApiQAxWidget
-from koapy.pyqt5.KiwoomOpenApiTrayApplication import KiwoomOpenApiTrayApplication
+from koapy.pyside2.KiwoomOpenApiQAxWidget import KiwoomOpenApiQAxWidget
+from koapy.pyside2.KiwoomOpenApiTrayApplication import KiwoomOpenApiTrayApplication
 
 from koapy.grpc.KiwoomOpenApiServiceServer import KiwoomOpenApiServiceServer
 from koapy.grpc.KiwoomOpenApiServiceClient import KiwoomOpenApiServiceClient
