@@ -42,7 +42,7 @@ def serve(port, verbose, no_verbose, args):
     if not no_verbose and verbose > 0:
         app_args.append('-' + 'v' * verbose)
     app_args += list(args)
-    from koapy.pyqt5.KiwoomOpenApiTrayApplication import KiwoomOpenApiTrayApplication
+    from koapy.pyside2.KiwoomOpenApiTrayApplication import KiwoomOpenApiTrayApplication
     KiwoomOpenApiTrayApplication.main(app_args)
 
 @cli.command(context_settings=CONTEXT_SETTINGS, short_help='Ensure logged in when server is up.')
@@ -83,18 +83,24 @@ def update():
     pass
 
 @update.command(context_settings=CONTEXT_SETTINGS, short_help='Update openapi TR metadata.')
+@click.option('-p', '--port', metavar='PORT', help='Port number of grpc server (optional).')
 @click.option('-v', '--verbose', count=True, help='Verbosity.')
-def trdata(verbose):
+def trdata(port, verbose):
     set_verbosity(verbose)
+    from koapy import KiwoomOpenApiContext
     from koapy.openapi.TrInfo import TrInfo
-    TrInfo.dump_trinfo_by_code()
+    with KiwoomOpenApiContext(port=port, client_check_timeout=client_check_timeout) as context:
+        TrInfo.dump_trinfo_by_code(context=context)
 
 @update.command(context_settings=CONTEXT_SETTINGS, short_help='Update openapi realtype metadata.')
+@click.option('-p', '--port', metavar='PORT', help='Port number of grpc server (optional).')
 @click.option('-v', '--verbose', count=True, help='Verbosity.')
-def realdata(verbose):
+def realdata(port, verbose):
     set_verbosity(verbose)
+    from koapy import KiwoomOpenApiContext
     from koapy.openapi.RealType import RealType
-    RealType.dump_realtype_by_desc()
+    with KiwoomOpenApiContext(port=port, client_check_timeout=client_check_timeout) as context:
+        RealType.dump_realtype_by_desc(context=context)
 
 @cli.group(context_settings=CONTEXT_SETTINGS, short_help='Get various types of data.')
 def get():
@@ -115,10 +121,10 @@ market_codes = [
 ]
 
 @get.command(context_settings=CONTEXT_SETTINGS, short_help='Get stock codes.')
+@click.option('-n', '--name', 'names', metavar='NAME', multiple=True, help='Name of stock. Can set multiple times.')
 @click.option('-m', '--market', 'markets', metavar='MARKET', multiple=True, type=click.Choice(market_codes, case_sensitive=False), help='Stock market code to get. Can set multiple times.')
-@click.option('-n', '--name', metavar='NAME', help='Name of stock.')
 @click.option('-p', '--port', metavar='PORT', help='Port number of grpc server (optional).')
-def stockcode(markets, name, port):
+def stockcode(names, markets, port):
     """
     \b
     Possible market codes are:
@@ -138,15 +144,18 @@ def stockcode(markets, name, port):
       all: All possible market codes.
     """
 
-    if (markets, name) == (tuple(), None):
-        fail_with_usage()
+    markets_option = markets
+
+    if (markets, names) == (tuple(), tuple()):
+        # fail_with_usage()
+        pass
 
     from koapy import KiwoomOpenApiContext
 
     with KiwoomOpenApiContext(port=port, client_check_timeout=client_check_timeout) as context:
         context.EnsureConnected()
 
-        if name is not None and not markets:
+        if not names and not markets:
             markets = ['0']
 
         if 'all' in markets:
@@ -159,17 +168,40 @@ def stockcode(markets, name, port):
 
         codes = sorted(list(codes))
 
-        if not name:
+        if markets_option:
             for code in codes:
                 click.echo(code)
         else:
-            names = [context.GetMasterCodeName(code) for code in codes]
-            codes_by_name = dict(zip(names, codes))
-            code = codes_by_name.get(name, None)
-            if code:
-                click.echo(code)
-            else:
-                click.echo('Cannot find code for given name.')
+            def get_names():
+                if names:
+                    if '-' in names:
+                        with click.open_file('-', 'r') as f:
+                            for name in f:
+                                yield name.strip()
+                    else:
+                        for name in names:
+                            yield name
+                else:
+                    while True:
+                        try:
+                            name = click.prompt('name', prompt_suffix=' >>> ')
+                            name = name.strip()
+                            if name == 'exit':
+                                break
+                            if name:
+                                yield name
+                        except EOFError:
+                            break
+
+            all_names = [context.GetMasterCodeName(code) for code in codes]
+            codes_by_name = dict(zip(all_names, codes))
+
+            for name in get_names():
+                code = codes_by_name.get(name, None)
+                if code:
+                    click.echo(code)
+                else:
+                    click.echo('Cannot find code for given name: %s.' % name)
 
 @get.command(context_settings=CONTEXT_SETTINGS, short_help='Get name for stock codes.')
 @click.option('-c', '--code', 'codes', metavar='CODE', multiple=True, help='Stock code to get. Can set multiple times.')
@@ -626,7 +658,24 @@ def holidays(output, offline, update, no_update, verbose):
             from koapy.utils.krx.marketdata.holiday import download_holidays_as_dict
             response = download_holidays_as_dict()
         else:
-            from koapy.utils.krx.calendar import get_holidays_as_dict
+            def get_holidays():
+                import datetime
+                from koapy.utils.krx.calendar.KrxHolidayCalendar import KrxHolidayCalendar
+                today = datetime.datetime.today()
+                calendar = KrxHolidayCalendar()
+                start = datetime.datetime(today.year, 1, 1)
+                end = datetime.datetime(today.year, 12, 31)
+                holidays = calendar.holidays(start, end, return_name=True)
+                return holidays
+            def get_holidays_as_dict():
+                holidays = get_holidays()
+                response = {'block1': [{
+                    'calnd_dd_dy': dt.strftime('%Y-%m-%d'),
+                    'kr_dy_tp': dt.strftime('%a'),
+                    'dy_tp_cd': dt.strftime('%a'),
+                    'holdy_nm': name,
+                } for dt, name in holidays.items() if dt.weekday() < 5]}
+                return response
             response = get_holidays_as_dict()
         lang = locale.getdefaultlocale()[0]
         if lang == 'ko_KR':
